@@ -54,11 +54,9 @@ class Hx():
             else:code='sz'+code
             temp_list.append(self.get_real_data(code)['price'])
         cang_df['市价']=temp_list
-        #cang_df['成本值']=cang_df['成本价']*cang_df['可用余额']
-        cang_df['新市值']=cang_df['市价']*cang_df['可用余额']
-        cang_df['盈亏']=cang_df['新市值']-cang_df['市值']
-        cang_df['盈亏比(%)']=round((cang_df['新市值']-cang_df['市值'])/cang_df['市值']*100,2)  
-        cang_df=cang_df.round(2)
+        cang_df['盈亏']=(cang_df['市价']-cang_df['成本价'])*cang_df['可用余额']
+        cang_df['盈亏比(%)']=round((cang_df['市价']-cang_df['成本价'])/cang_df['成本价']*100,2)
+        cang_df['市值']=cang_df['市价']*cang_df['可用余额']
         return cang_df
     #获取资金
     def get_money(self):
